@@ -471,9 +471,9 @@ function find_needle_in_haystack(haystack, needle)
         k == needle && return StructUtils.EarlyReturn(v)
     end
     ret isa StructUtils.EarlyReturn && return ret.value
-    throw(ArgumentError("needle not found in haystack")
+    throw(ArgumentError("needle not found in haystack"))
 end
-````
+```
 """
 struct EarlyReturn{T}
     value::T
@@ -805,10 +805,10 @@ else
 end
 
 macro _t(i)
-    esc(:(@inbounds(vals[$i]::fieldtype(T, $i))))
+    esc(:(isassigned(vals, $i) ? @inbounds(vals[$i])::fieldtype(T, $i) : fielddefault(style, T, $i)::fieldtype(T, $i)))
 end
 
-@generated function _tuple(::Type{T}, vals) where {T}
+@generated function _tuple(::Type{T}, vals, style) where {T}
     n = fieldcount(T)
     ex = Expr(:block)
     push!(ex.args, :(Base.@_inline_meta))
@@ -849,7 +849,7 @@ function maketuple(style, ::Type{T}, source) where {T}
     GC.@preserve ref begin
         i = Base.unsafe_convert(Ptr{Int}, ref)
         st = applyeach(style, TupleClosure{T,typeof(vals),typeof(style)}(vals, style, i), source)
-        return _tuple(T, vals), st
+        return _tuple(T, vals, style), st
     end
 end
 
@@ -983,7 +983,7 @@ function makestruct(style, ::Type{T}, source) where {T}
     fstrs = fieldnamestrings(T)
     st = applyeach(style, StructClosure{T}(vals, style, fsyms, fstrs), source)
     if T <: NamedTuple
-        return T(_tuple(T, vals)), st
+        return T(_tuple(T, vals, style)), st
     else
         return _construct(T, vals, style, fsyms), st
     end
